@@ -1,7 +1,8 @@
 from .jupyter import running_as_notebook
-from .pyplot_visualizer import SliderSystem
 from .multibody import ManipulatorDynamics
+from .plot_utils import plot_2d_phase_portrait
+from .pyplot_utils import SliderSystem
+
 # Note: can't import running_as_test here.  Will get a copy instead of a
 # reference.
-from .utils import FindResource
-from .plot_utils import plot_2d_phase_portrait
+from .utils import ConfigureParser, FindResource
